# lcpy

Lowercase stuff in Python

## How to Use

You can use any of the following values in your code:

* `true`
* `false`
* `none`

By doing:

```python
from lcpy import true
```

or...

```python
from lcpy import false, none
```

... for example.
